require(symbolicDA)
data("cars",package="symbolicDA")
save.SO(cars,file="cars_backup.xml")
